@@ -1,7 +1,7 @@
 """Tensorleap CLI.
 
 Usage:
-  leap init (--tensorflow|--pytorch) [PROJECT] [ORG] [DATASET]
+  leap init (--tensorflow|--pytorch) [PROJECT] [ORG] [DATASET] [BUCKET]
   leap login [API_ID] [API_KEY]
   leap check
   leap push
@@ -67,17 +67,29 @@ def complain(text: str):
 def login_command(arguments: dict):
     project = Project(os.getcwd())
     if not project.is_initialized():
-        complain('''Tensorleap project not initialized.Did you run `leap init`?''')
+        complain('Tensorleap project not initialized.\n'
+                 'Did you run `leap init`?')
 
     if arguments['API_ID'] is not None and arguments['API_KEY'] is None:
-        complain(f'''Either supply both API_ID and API_KEY or neither. {__doc__}''')
+        complain(f'Either supply both API_ID and API_KEY or neither.\n'
+                 f'{__doc__}')
     try:
-        auth = Authenticator(project)
-        auth.cli_login(arguments.get('API_ID', None), arguments.get('API_KEY', None))
+        api_id = arguments.get('API_ID')
+        api_key = arguments.get('API_KEY')
+        if api_id is None:
+            api_id = input('API ID: ')
+            if api_key is None:
+                api_key = input('API Key: ')
+
+        Authenticator.initialize(project, api_id, api_key, should_write_credentials=True)
+        print(f'Authenticated as {Authenticator.user.local.email}')
+
     except MalformedKeys:
-        complain(f'''Invalid API_ID or API_KEY. {__doc__}''')
+        complain(f'Invalid API_ID or API_KEY.\n'
+                 f'{__doc__}')
     except KeysMixedUp:
-        complain(f'''API_ID should come before API_KEY. {__doc__}''')
+        complain(f'API_ID should come before API_KEY.\n'
+                 f'{__doc__}')
     except NotFoundException:
         complain('❗️ Login failed. Check the API_ID provided.')
     except UnauthorizedException:
@@ -104,11 +116,13 @@ def init_command(arguments: Dict):
         initializer.init_project(framework,
                                  arguments.get('PROJECT'),
                                  arguments.get('ORG'),
-                                 arguments.get('DATASET'))
+                                 arguments.get('DATASET'),
+                                 arguments.get('BUCKET'))
         print(f'Tensorleap project initialized in {TENSORLEAP_DIR}')
     except AlreadyInitialized:
         expected_conf = Path(TENSORLEAP_DIR).joinpath(CONFIG_FILENAME)
-        complain(f'''Tensorleap project already initialized. See {expected_conf}''')
+        complain(f'Tensorleap project already initialized.\n'
+                 f'See {expected_conf}')
     except InvalidProjectName:
         complain(f'Invalid project name. Rules:\n{VALID_PROJECT_EXPL}')
     except InvalidOrgName:
