@@ -9,6 +9,14 @@ class InvalidProjectName(Exception):
     pass
 
 
+class ProjectNotInitialized(Exception):
+    pass
+
+
+class CredentialsNotFound(Exception):
+    pass
+
+
 class InvalidOrgName(Exception):
     pass
 
