@@ -13,7 +13,7 @@ from git.exc import InvalidGitRepositoryError
 import toml
 from openapi_client.apis import DefaultApi
 
-from leapcli.exceptions import InvalidOrgName, InvalidProjectName, AlreadyInitialized
+from leapcli.exceptions import InvalidOrgName, CredentialsNotFound, AlreadyInitialized, InvalidProjectName
 
 
 class Framework(str, enum.Enum):
@@ -49,6 +49,7 @@ class Project:
         self.framework: Framework = Framework.TENSORFLOW
         self.state = {}
         self.dataset: Optional[str] = None
+        self.bucket: Optional[str] = None
 
     def detect_project_dir(self) -> Path:
         try:
@@ -60,20 +61,25 @@ class Project:
     def detect_project(self) -> str:
         if self.is_initialized():
             return self.project_config()['projectName']
-        return os.path.basename(self.detect_project_dir())
+        raise CredentialsNotFound()
 
     def detect_dataset(self) -> str:
         if self.is_initialized():
             return self.project_config()['datasetName']
-        return os.path.basename(self.detect_project_dir())
+        raise CredentialsNotFound()
 
-    def prompt_dataset(self) -> str:
-        default = self.detect_dataset()
-        return input(f'Dataset name ({default}): ') or default
+    def detect_bucket(self) -> str:
+        if self.is_initialized():
+            return self.project_config()['bucketName']
+        raise CredentialsNotFound()
 
-    def prompt_project(self) -> str:
-        default = self.detect_project()
-        return input(f'Project name ({default}): ') or default
+    @staticmethod
+    def prompt_dataset() -> str:
+        return input('Dataset name: ')
+
+    @staticmethod
+    def prompt_project() -> str:
+        return input('Project name: ')
 
     def org_domain(self) -> str:
         return f'{self.detect_org()}.{TENSORLEAP_BACKEND_DOMAIN}'
@@ -200,16 +206,16 @@ class Project:
     def is_initialized(self):
         return self.tensorleap_dir().is_dir()
 
-    def init_project(self, framework: Framework, project: Optional[str] = None,
-                     org: Optional[str] = None, dataset: Optional[str] = None):
+    def init_project(self, framework: Framework, project: str, org: str, dataset: str, bucket: str):
         if self.is_initialized():
             raise AlreadyInitialized()
         self.project = project or self.prompt_project()
         Project.validate_project_name(self.project)
-        self.org = org or self.prompt_org()
+        self.org = org
         Project.validate_org_name(self.org)
-        self.dataset = dataset or self.prompt_dataset()
+        self.dataset = dataset
         self.framework = framework
+        self.bucket = bucket
         self._generate_project_template()
 
     def config_file_path(self) -> Path:
@@ -234,6 +240,7 @@ class Project:
             txt = txt.replace('ORG', self.org)
             txt = txt.replace('FRAMEWORK', self.framework)
             txt = txt.replace('DATASET', self.dataset)
+            txt = txt.replace('BUCKET', self.bucket)
 
         with open(self.config_file_path(), 'w', encoding='utf-8') as config_file:
             config_file.write(txt)
@@ -247,4 +254,3 @@ class Project:
 
     def dataset_py_path(self) -> Path:
         return self._integration_file_py_path('dataset')
-
